:py:mod:`user_defined_function_1i1o_com`
========================================

.. py:module:: user_defined_function_1i1o_com


Module Contents
---------------

.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: Exec
   

   Properties of the generated Node


.. py:data:: BaseName
   :annotation: = User Defined Function 1I 1O

   

.. py:data:: NodeAttributeNames
   :annotation: = ['Parameters', 'Input', 'Output']

   

.. py:data:: NodeAttributeType
   :annotation: = ['Static', 'Input', 'Output']

   

.. py:data:: ParameterNames
   :annotation: = ["Full path to function's filename"]

   

.. py:data:: ParameterTypes
   :annotation: = ['str']

   

.. py:data:: ParametersDefaultValues
   :annotation: = ['E:\\Temp\\function.py']

   

.. py:data:: WorkerDefaultExecutable
   

   

.. py:data:: transform_template_com
   

   

